var EXPORTED_SYMBOLS = ["Delete"];
Components.utils.import('resource://indexdata/runtime/Step.js');
Components.utils.import('resource://indexdata/util/xulHelper.js');
Components.utils.import('resource://indexdata/util/jsonPathHelper.js');
var Delete = function () { this.conf = {}; };
Delete.prototype = new Step();
Delete.prototype.constructor = Delete;
Delete.prototype.init = function() {};
Delete.prototype.draw = function(surface) {
  xulHelper.jsonPathField(surface, this, this.conf, "target", "",
                    null, { rwmode:"r", containermode:"anynode" } );
    // marked as a read mode, since we are not writing into it, and
    // do not want the replace/append options
};
Delete.prototype.run = function (task) {
  jsonPathHelper.set(this.conf.target, undefined, task.data)
};
Delete.prototype.getClassName = function () { return "Delete"; };
Delete.prototype.getDisplayName = function () { return "Delete"; };
Delete.prototype.getDescription = function () { return ""; };
Delete.prototype.getVersion = function () { return "1.0"; };
Delete.prototype.getUsedArgs = function () { return []; };
Delete.prototype.renderArgs = function () {
  return this.conf.target ? this.conf.target.key : "";
};
Delete.prototype.upgrade = function (confVer, curVer, conf) {
  if (confVer > curVer) return false;
  return true;
};
